import json


class Str(str):
    pass


class Float(float):
    pass


class Int(int):
    pass


class Dict(dict):
    pass


class List(list):
    pass


def make_response(items):
    res = []
    for item in items:
        item_data = item["data"]

        try:
            item_data = json.loads(item_data)
        except:
            ...

        try:
            if "." in item_data:
                item_data = float(item_data)
            item_data = int(item_data)
        except:
            ...

        formatted = None
        if type(item_data) == str:
            formatted = Str(item_data)
            try:
                formatted.size = item["size"]
                formatted.total_size = item["total_size"]

                formatted.content_type = item["content_type"]
                formatted.created = item["created"]
                formatted.updated = item["updated"]
            except:
                pass

        elif type(item_data) == float:
            formatted = Float(item_data)
            try:
                formatted.size = item["size"]
                formatted.total_size = item["total_size"]

                formatted.content_type = item["content_type"]
                formatted.created = item["created"]
                formatted.updated = item["updated"]
            except:
                pass

        elif type(item_data) == int:
            formatted = Int(item_data)
            try:
                formatted.size = item["size"]
                formatted.total_size = item["total_size"]

                formatted.content_type = item["content_type"]
                formatted.created = item["created"]
                formatted.updated = item["updated"]
            except:
                pass

        elif type(item_data) == dict:
            formatted = Dict(item_data)
            try:
                formatted.size = item["size"]
                formatted.total_size = item["total_size"]

                formatted.content_type = item["content_type"]
                formatted.created = item["created"]
                formatted.updated = item["updated"]
            except:
                pass

        elif type(item_data) == list:
            formatted = List(item_data)
            try:
                formatted.size = item["size"]
                formatted.total_size = item["total_size"]

                formatted.content_type = item["content_type"]
                formatted.created = item["created"]
                formatted.updated = item["updated"]
            except:
                pass
        if formatted:
            res.append(formatted)

    return res



import json

import requests

from huddu.utils.exceptions import APIException


class Session:
    def __init__(
            self, collection: str, token: str, region: str, base_url: str = "https://connect.huddu.io"
    ):
        self.collection = collection
        self.token = token
        self.region = region
        self.base_url = base_url

    def _request(self, method, params: dict = None, data: dict = None):
        headers = {"Authorization": f"Token {self.token}",
                   "Collection": self.collection,
                   "Region": self.region
                   }

        if data:
            res = requests.request(
                method,
                f"{self.base_url}/documents",
                data=json.dumps(data),
                headers=headers,
            )
        else:
            res = requests.request(
                method, f"{self.base_url}/documents", params=params, headers=headers
            )

        if res.status_code > 299:
            raise APIException(res.json())
        return res.json()

    def create_documents(self, items: list):
        for i in items:
            try:
                i["data"] = json.dumps(i["data"])
            except:
                i["data"] = str(i["data"])
                
        return self._request("POST", data={"items": items})

    def list_documents(
            self,
            ids: list = None,
            limit: int = 25,
            skip: int = 0,
            start: int = 0,
            end: int = 0,
    ):
        params = {}

        if ids:
            params["ids"] = ",".join(ids)
        if start:
            params["start"] = start
        if end:
            params["end"] = end
        if limit:
            params["limit"] = limit
        if skip:
            params["skip"] = skip

        return self._request("GET", params=params)

    def delete_documents(self, ids: list):
        return self._request("DELETE", data={"ids": ids})
